@@ -6,6 +6,31 @@ use Google::ProtocolBuffers::Dynamic::ProtocInterface;
 
 sub import {
     my ($class, %args) = @_;
+
+    if (@ARGV && grep /^(?:--help|-h)$/, @ARGV) {
+        my $message = 'This is a protoc plugin and should not be used directly. Use --man for documentation';
+
+        if ('podusage' eq ($args{help} // '')) {
+            require Pod::Usage;
+
+            Pod::Usage::pod2usage(
+                -message => $message . "\n",
+                -exitval => 1,
+            );
+        } else {
+            print STDERR $message, "\n\n";
+
+            exit 1;
+        }
+    } elsif (@ARGV && grep /^--man$/, @ARGV) {
+        require Pod::Usage;
+
+        Pod::Usage::pod2usage(
+            -exitval => 0,
+            -verbose => 2,
+        );
+    }
+
     my $generator = $args{run};
     eval "require $generator; 1"
         or die "Error loding plugin '$generator': $@";
@@ -51,7 +76,7 @@ Google::ProtocolBuffers::Dynamic::ProtocPlugin
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 AUTHOR
 
