@@ -8,6 +8,7 @@
 
 using namespace gpd;
 using namespace std;
+using namespace UMS_NS;
 using namespace google::protobuf;
 using namespace upb;
 using namespace upb::googlepb;
@@ -94,7 +95,6 @@ namespace {
 MappingOptions::MappingOptions(pTHX_ SV *options_ref) :
         use_bigints(sizeof(IV) < sizeof(int64_t)),
         check_required_fields(true),
-        ignore_undef_fields(false),
         explicit_defaults(false),
         encode_defaults(false),
         encode_defaults_proto3(false),
@@ -102,12 +102,13 @@ MappingOptions::MappingOptions(pTHX_ SV *options_ref) :
         generic_extension_methods(true),
         implicit_maps(false),
         decode_blessed(true),
+        fail_ref_coercion(false),
         no_redefine_perl_names(false),
+        ignore_undef_fields(false),
+        boolean_style(Perl),
         accessor_style(GetAndSet),
         client_services(Disable),
-        boolean_style(Perl),
-        default_decoder(Upb),
-        fail_ref_coercion(false) {
+        default_decoder(Upb) {
     stack_trace = get_stack_trace(aTHX);
 
     if (options_ref == NULL || !SvOK(options_ref))
@@ -187,7 +188,7 @@ Dynamic::Dynamic(const string &root_directory) :
 }
 
 Dynamic::~Dynamic() {
-    for (STD_TR1::unordered_map<std::string, const Mapper *>::iterator it = descriptor_map.begin(), en = descriptor_map.end(); it != en; ++it)
+    for (unordered_map<std::string, const Mapper *>::iterator it = descriptor_map.begin(), en = descriptor_map.end(); it != en; ++it)
         it->second->unref();
 }
 
@@ -377,7 +378,7 @@ void Dynamic::map_package_prefix(pTHX_ const string &pb_prefix, const string &pe
 void Dynamic::map_package_or_prefix(pTHX_ const string &pb_package_or_prefix, bool is_prefix, const string &perl_package_prefix, const MappingOptions &options) {
     string prefix_and_dot = pb_package_or_prefix + ".";
 
-    for (STD_TR1::unordered_set<const FileDescriptor *>::iterator it = files.begin(), en = files.end(); it != en; ++it) {
+    for (unordered_set<const FileDescriptor *>::iterator it = files.begin(), en = files.end(); it != en; ++it) {
         const FileDescriptor *file = *it;
         const string &file_package = file->package();
         bool is_exact = false;
@@ -434,7 +435,7 @@ void Dynamic::map_package_or_prefix(pTHX_ const string &pb_package_or_prefix, bo
 void Dynamic::map_message_prefix(pTHX_ const string &message, const string &perl_package_prefix, const MappingOptions &options) {
     const DescriptorPool *pool = descriptor_loader.pool();
     const Descriptor *descriptor = pool->FindMessageTypeByName(message);
-    STD_TR1::unordered_set<std::string> recursed_names;
+    unordered_set<std::string> recursed_names;
 
     if (descriptor == NULL) {
         croak("Unable to find a descriptor for message '%s'", message.c_str());
@@ -500,7 +501,7 @@ std::string Dynamic::pbname_to_package(pTHX_ const std::string &pb_name, const s
     return oss.str();
 }
 
-void Dynamic::map_message_prefix_recursive(pTHX_ const Descriptor *descriptor, const string &perl_package_prefix, const MappingOptions &options, STD_TR1::unordered_set<std::string> &recursed_names) {
+void Dynamic::map_message_prefix_recursive(pTHX_ const Descriptor *descriptor, const string &perl_package_prefix, const MappingOptions &options, unordered_set<std::string> &recursed_names) {
 	// avoid recursion loop
 	if (recursed_names.find(descriptor->full_name()) != recursed_names.end())
 		return;
@@ -514,14 +515,18 @@ void Dynamic::map_message_prefix_recursive(pTHX_ const Descriptor *descriptor, c
 			map_message_prefix_recursive(aTHX_ message, perl_package_prefix, options, recursed_names);
 			break;
 		}
-		case FieldDescriptor::Type::TYPE_ENUM:
+		case FieldDescriptor::Type::TYPE_ENUM: {
 			const EnumDescriptor *enumm = field->enum_type();
 			if (mapped_enums.find(enumm->full_name()) == mapped_enums.end()) {
 				std::string perl_package =
 					pbname_to_package(aTHX_ enumm->full_name(), perl_package_prefix);
 				map_enum(aTHX_ enumm, perl_package, options);
 			}
+                }
 			break;
+                default:
+                    // nothing to do; suppress warning
+                    break;
 		}
 
 	}
@@ -825,7 +830,7 @@ void Dynamic::resolve_references() {
 }
 
 const Mapper *Dynamic::find_mapper(const MessageDef *message_def) const {
-    STD_TR1::unordered_map<string, const Mapper *>::const_iterator item = descriptor_map.find(message_def->full_name());
+    unordered_map<string, const Mapper *>::const_iterator item = descriptor_map.find(message_def->full_name());
 
     if (item == descriptor_map.end())
         croak("Unknown type '%s'", message_def->full_name());
